## Tilastotieteen käsikirja / R-esimerkit lukuun 8
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
fibon<-c(1,1,2,3,5,8,13,21) # Luodaan vektori
plot(fibon) # Kuvataan tulokset

## --------------------------------------------------------------------------------------------------------------------------------
plot( x = fibon,
      main = "Pääotsikon parametri on 'main'",
      sub = "Alaotsikon parametri on 'sub'",
      xlab = "X-akselin otsikon parametri on 'xlab'",
      ylab = "Y-akselin otsikon parametri on 'ylab'", 
)

## --------------------------------------------------------------------------------------------------------------------------------
par(mfrow=c(2,3)) # Kuviomatriisin koko riveinä ja sarakkeina
plot(fibon,main="type='p'",xlab = "",ylab="",type="p") # Pisteet
plot(fibon,main="type='l'",xlab = "",ylab="",type="l") # Viiva
plot(fibon,main="type='o'",xlab = "",ylab="",type="o") # Pisteet ja viiva
plot(fibon,main="type='b'",xlab = "",ylab="",type="b") # Pisteet ja katkaistu viiva
plot(fibon,main="type='h'",xlab = "",ylab="",type="h") # Pystyvuuvat
plot(fibon,main="type='s'",xlab = "",ylab="",type="s") # Porrasfunktio
## --------------------------------------------------------------------------------------------------------------------------------
par(mfrow=c(1,1))
plot(fibon,
     type = "b", # Tyyppi
     col = "steelblue1", # Väri
     pch = 17, # Merkkien tyyppi
     cex=3, # Merkkien koko
     lty=3, # Viivan tyyppi
     lwd=4) # Viivan paksuus

## --------------------------------------------------------------------------------------------------------------------------------
# Luodaan vektoreita kuvatavaksi
Muuttuja1<-c(2,4,8,16,32,64) # Fibonaccin lukujono
Muuttuja2<-rnorm(1000,20,5) # Satunnaislukuja
Muuttuja3<-rnorm(1000,30,2) # Satunnaislukuja
Muuttuja4<-as.factor(c('Ilves','Ilves','Ilves','Ilves','Ilves','TPS','TPS')) # Tekijä

# Piirretään kuvaajat
par(mfrow=c(1,3)) # Kuvaajien asettelu
plot(Muuttuja1) # Pistekuvaaja
plot(Muuttuja2,Muuttuja3) # Sirontakuvio	
plot(Muuttuja4) # Pylväskuvaaja


## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan kirjan datapaketti
library(nummenmaa)

## --------------------------------------------------------------------------------------------------------------------------------
par(mfrow=c(1,2))
hist(insuliini$BMI,xlim=c(10,50), # Histogrammi, säädetään x-akseli
     xlab="BMI",ylab="Lukumäärä", # Akselien otsikot 
     main="BMI:n histogrammi",col="grey") # Pääotsikko ja väri

hist(insuliini$BMI,xlim=c(10,50), # Histogrammi, säädetään x-akseli
     xlab="BMI",ylab="Lukumäärä", # Akselien selitteet
     main="BMI:n histogrammi", # Pääotsikko
     col="grey95",border = "grey55", # Täyttöväri ja viivan väri
     breaks = 20) # Kasvatetaan pylväiden määrää
## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään laatikko-jana -kuvaajia

par(mfrow=c(1,2)) # Kuvaajien asettelu

# Laatikko-jana -kuvio yhdestä muuttujasta
boxplot(insuliini$PAASTOGLUK, 
        xlab="",ylab="Paastoglukoosi",   # Akselien otsikot
        main="Paastoglukoosi koko aineistossa")       # Pääotsikko

# Laatikko-jana -kuvio luokittain
boxplot(insuliini$PAASTOGLUK~insuliini$DIABETES, 
        xlab="Paastoglukoosi",ylab="Diabetes",   # Akselien otsikot
        main="Paastoglukoosi diabetesryhmissä",
        boxfill=c("grey55","grey85"),boxcol=c("grey55","grey85"), # Laatikoiden värit
        whiskcol = ("grey55"), # Janojen värit, sama molemmille ryhmille
        horizontal=TRUE,  notch=TRUE # Vaakasuunta
)   


## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään pylväskuvioita

par(mfrow=c(1,3)) # Kuvaajien asettelu

# Pylväskuvaaja
barplot(table(insuliini$SUKUP), 
        col="grey95")

# Pylväskuvio ristiintaulukoituna 
barplot(table(insuliini$SUKUP,insuliini$DIABETES), 
        beside=TRUE,xlab="Diabetes",ylab="Lukumäärä", # Luokat vierkkäin eikä päällekäin
        legend=TRUE,main="Diabetes ja insuliinitasot") # Luokkien nimiöt ja otsikot

# Sektorikuvio
pie(table(insuliini$SOKERITASAP), 	
    main="Sokeritasapaino") # Kuvaajan otsikko

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan ggplot2 ja kokeillaan sen käyttöä
library(ggplot2)
library(gridExtra)


## --------------------------------------------------------------------------------------------------------------------------------
## Nopeat qplot-kuvaajat
plot1<-qplot(data=suhteet,SUKUP) 
plot2<-qplot(data=suhteet,PITUUS,PAINO)
grid.arrange(plot1, plot2, ncol=2)


## --------------------------------------------------------------------------------------------------------------------------------
# Pylväskuvaaja

plot1=qplot(data=suhteet,SUKUP,main="Sukupuolen frekvenssijakauma", 
            xlab="Sukupuoli",ylab="Lukumäärä", fill=SUKUP)+ # Otsikoinnit
  theme_light()+scale_fill_grey() # Kevyt ulkoasu

# Sirontakuvio
plot2=qplot(data=suhteet,PITUUS,PAINO,main="Pituuden ja painon sirontakuvio",  
            xlab="Pituus",colour=SUKUP,ylab="Paino") + # Otsikoinnit
  theme_bw()+scale_color_grey()	# Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## --------------------------------------------------------------------------------------------------------------------------------
# Pylväskuvio
plot1=qplot(data=suhteet, PARISUHDE, geom="bar",
            xlab="Sukupuoli",ylab="Lukumäärä",fill=PARISUHDE) + #Otsikoinnit ja väritys
  theme_light() +scale_fill_grey() # Kevyt ulkoasu

# Pylväskuvio ristiintaulukoituna
plot2=qplot(data=suhteet, PARISUHDE, geom="bar", 
            xlab="Sukupuoli",ylab="Lukumäärä",fill=SUKUP)+ #Otsikoinnit ja väritys
  theme_light() +scale_fill_grey() # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## ----fig.height=3, fig.width=8---------------------------------------------------------------------------------------------------
# Histogrammi
plot1=qplot(PAINO, data = suhteet, geom = "histogram",bins=30, 
            xlab="Paino",ylab="Lukumäärä") + # Otsikoinnit
  theme_minimal() # Kevyt ulkoasu

# Histogrammi luokittain
plot2=qplot(PAINO, data = suhteet, 
            geom = "histogram",fill=PARISUHDE,bins=50, 
            xlab="Paino",ylab="Lukumäärä") + # Otsikoinnit
  theme_minimal() +scale_fill_grey() # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## --------------------------------------------------------------------------------------------------------------------------------
# Estimoitu tiheysfunktio
plot1=qplot(PAINO, data = suhteet, geom = "density", 
            xlab="Paino",ylab="Tiheys") + #Otsikoinnit
  theme_light() # Kevyt ulkoasu

# Tiheysfunktio luokittain
plot2=qplot(PAINO, data = suhteet, geom = "density", 
            linetype=PARISUHDE, color=PARISUHDE, # Viiva- ja väriasetukset luokille
            xlab="Paino",ylab="Tiheys") + # Otsikoinnit
  theme_light() # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## --------------------------------------------------------------------------------------------------------------------------------
# Laatikko-jana-kuvio
plot1=qplot(x=1,SEKS_AKTIIVISUUS,data=suhteet, 
            geom="boxplot", 
            xlab="",ylab="Seksuaalinen aktiivisuus") + # Tyhjä otsikointi x-akselille
  theme_light() # Kevyt ulkoasu

# Laatikko-jana-kuvio luokittain
plot2=qplot(PARISUHDE,SEKS_AKTIIVISUUS,data=suhteet, 
            geom="boxplot", 
            xlab="Parisuhteen tyyppi",ylab="Seksuaalinen aktiivisuus") + # Otsikoinnit
  theme_light()  # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## --------------------------------------------------------------------------------------------------------------------------------
# Laatikko-jana kuvio kahdella luokalla
qplot(PARISUHDE,SEKS_AKTIIVISUUS,data=suhteet, 
      geom="boxplot",fill=SUKUP,
      xlab="Parisuhteen tyyppi",ylab="Seksuaalinen aktiivisuus") +  # Otsikoinnit
  theme_light() +scale_fill_grey() # Kevyt ulkoasu


## --------------------------------------------------------------------------------------------------------------------------------
# Pistekuvaaja
plot1=qplot(PARISUHDE,SEKS_AKTIIVISUUS,data=suhteet, geom=c("dotplot"), 
            stackdir = "center",binaxis = "y",binwidth=0.075, # Pisteiden asetukset
            xlab="Parisuhteen tyyppi",ylab="Seksuaalinen aktiivisuus") + # Otsikoidaan
  theme_light() # Kevyt ulkoasu

# Viulukuvaaja, värit luokittain
plot2=qplot(PARISUHDE,SEKS_AKTIIVISUUS,data=suhteet, 
            geom="violin",fill=PARISUHDE, 
            xlab="Parisuhteen tyyppi", ylab="Seksuaalinen aktiivisuus") + # Otsikot
  theme_light() +scale_fill_grey() # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## --------------------------------------------------------------------------------------------------------------------------------
# Yksinkertainen histogrammi
plot1<-ggplot(insuliini,aes(x=DIASTVP))+
  geom_histogram() # Määritellään tyypiksi histogrammi
plot1
plot1+ labs(title="Verenpaineen histogrammi", # Lisätään pääotsikko
            x="Verenpaine (mmHg)", y = "Lukumäärä")    # Lisätään akselien selitteet


## --------------------------------------------------------------------------------------------------------------------------------
# Kuvaajan asetusten muokkaaminen
plot1<-ggplot(insuliini, aes(x=VYOTARO)) +
  geom_histogram(color="black",fill="white") + # Histogrammi ja väriasetukset
  labs(title="Histogrammi", # Lisätään pääotsikko
       x="Vyötärönympärys", y = "Lukumäärä") + # Lisätään akselien selitteet
  theme_light() # Perinteinen ulkoasu
plot1


## --------------------------------------------------------------------------------------------------------------------------------
# Laatikko-jana -kuvio
plot1<-ggplot(insuliini, aes(y=VYOTARO,x="")) +
  geom_boxplot(notch=TRUE,color="darkblue",fill="lightblue") +
  labs(title="Laatikko-jana-kuvio", # Lisätään pääotsikko
       x="Tutkittavat", y = "Vyötärönympärys") + # Lisätään selitteet
  theme_light() # Kevyt ulkoasu
plot1 # Piirretään kuvaaja


## --------------------------------------------------------------------------------------------------------------------------------
# Laatikko-jana -kuvio luokittain
plot1 <- ggplot(insuliini, aes(x=SOKERITASAP, y=DIASTVP, fill=SOKERITASAP)) + 
  geom_boxplot(notch=TRUE) + # Lisätään lovi
  labs(title="Sokeritasapaino ryhmittäin", # Lisätään pääotsikko
       x="Sokeritasapaino", y = "Verenpaine") + # Lisätään akselien selitteet
  theme_light() + # Poistetaan ylimääräinen selite
  theme(legend.position="none") + # poistetaan ylimääräinen selite
  scale_fill_brewer(palette="YlOrRd") # Vaihdetaan värikartta

#  Laatikko-jana -kuvio datapisteillä
plot2 <- ggplot(insuliini, aes(x=SOKERITASAP, y=DIASTVP,fill=SOKERITASAP)) +
  geom_boxplot(notch=TRUE) +
  geom_dotplot(binaxis='y', stackdir='center', dotsize=0.5) +  # lisätään pistekuvaaja
  labs(title="Sokeritasapaino ryhmittäin", # lisätään pääotsikko
       x="Sokeritasapaino", y = "Verenpaine") + # lisätään akselien selitteet
   theme_light() + # Kevyt ulkoasu
  theme(legend.position="none") + # Poistetaan ylimääräinen selite
  scale_fill_brewer(palette="YlOrRd")  # Vaihdetaan värikartta
 
# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2)


## --------------------------------------------------------------------------------------------------------------------------------
# 2 X 3 laatikko-jana -kuvaaja
plot1 <- ggplot(insuliini, aes(x=SOKERITASAP, y=DIASTVP,fill=SUKUP)) + 
  geom_boxplot() +
  labs(title="Sokeritasapaino ryhmittäin", # Lisätään pääotsikko
       x="Sokeritasapaino", y = "Verenpaine") + # Lisätään akselien selitteet) +
  scale_fill_manual(values=c("#5a5a5a", "#c8c8c8")) + # Säädetään värejä
  theme_light() # Kevyt ulkoasu

# Vaakasuuntainen kuvaaja
plot2 <- ggplot(insuliini, aes(x=SOKERITASAP, y=DIASTVP,fill=SUKUP)) + 
  geom_boxplot() +
  labs(title="Sokeritasapaino ryhmittäin", # Lisätään pääotsikko
       x="Sokeritasapaino", y = "Verenpaine") + # Lisätään akselien selitteet) 
  scale_fill_manual(values=c("#999999", "#56B4E9")) + # Säädetään värejä
  coord_flip() + # Käännetään kuvaaja
  theme_light() # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2)


## --------------------------------------------------------------------------------------------------------------------------------
# Pylväskuvaaja keskiarvoista
plot1<-ggplot(insuliini, aes(y=BMI, x=SOKERITASAP)) +
  geom_bar(stat="summary",fun.y = "mean",fill="steelblue")+ # Kuvataan keskiarvo
  labs(title="BMI ryhmittäin", # Lisätään pääotsikko
       x="Sokeritasapaino", y = "BMI") + # Lisätään akselien selitteet
  theme_minimal() # Yksinkertainen ulkoasu

# 2 X 2 pylväskuvaaja
plot2<-ggplot(insuliini, aes(y=BMI, x=SOKERITASAP,fill=SUKUP)) + 
  geom_bar(stat="summary",fun.y = "mean",position="dodge") + # Kuvataan keskiarvo
  labs(title="BMI ryhmittäin", # Lisätään pääotsikko
       x="Sokeritasapaino", y = "BMI") + # Lisätään akselien selitteet
  theme_minimal() +scale_fill_grey() # Yksinkertainen ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2)


## --------------------------------------------------------------------------------------------------------------------------------
# Sirontakuvio
plot1<-ggplot(insuliini, aes(y=SYKE,x=DIASTVP)) + 
  geom_point(color="darkblue",fill="lightblue", # Määritellään sirontakuvio
             alpha=0.50) + # Läpinäkyvyys 
  ylim(25, 100) + # Säädetään akselit
  geom_smooth(method=lm) + # Lisätään regressiosuora
  labs(title="Verenpaine ja leposykeet", # Lisätään pääotsikko
       x="Verenpaine", y = "Leopsyke") + # Lisätään akselien selitteet
  theme_light() # Kevyt ulkoasu
plot1 # Piirretään kuvaaja



## --------------------------------------------------------------------------------------------------------------------------------
# Muokataan sirontakuviota
plot1+aes(y=SYKE,x=DIASTVP,size=BMI)+ # Lisätään BMI pisteiden kooksi
  geom_point(color="darkblue",fill="lightblue", # määritellään sirontakuvio
             alpha=0.1)+
  labs(title="Verenpaine ja leposykeet", # lisätään pääotsikko
       x="Verenpaine", y = "Leopsyke")


## --------------------------------------------------------------------------------------------------------------------------------
# Monimutkaisempi sirontakuvio
plot1<-ggplot(insuliini, aes(y=PITUUS,x=PAINO,color=SUKUP)) + 
  geom_point(alpha=0.50,size=3) + # Läpinäkyvyys ja pisteiden koko
  labs(title="Pituus ja paino", # Lisätään pääotsikko
       x="Paino", y = "Pituus") + # Lisätään akselien selitteet
  theme_minimal() +scale_color_grey() # Kevyt ulkoasu

# Muokataan sirontakuviota
plot2<-ggplot(insuliini, aes(y=PITUUS,x=PAINO,color=SUKUP,shape=SUKUP)) + 
  geom_point(alpha=0.50,size=3)+ # Läpinäkyvyys ja pisteiden koko
  geom_smooth(method=lm, aes(fill=SUKUP))+ # Regressiosuorat luottamusvälein 
  scale_color_manual(values = c("grey", "black"))+ # Muutetaan pisteiden väri
  scale_fill_manual(values = c("grey", "black"))+ # Muutetaan regressiosuoran väri
  labs(title="Pituus ja paino", # Lisätään pääotsikko
       x="Paino", y = "Pituus") + # Lisätään akselien selitteet
  theme_minimal() # Kevyt ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 


## --------------------------------------------------------------------------------------------------------------------------------
# 2 X 2 pylväskuvaaja
plot1<-ggplot(insuliini, aes(x=SOKERITASAP,fill=SUKUP)) + 
  geom_bar(stat="count")+
  labs(title="Sokeritasapaino", # Lisätään pääotsikko
       x="Sokeritasapaino", y = "Lukumäärä") + # Lisätään akselien selitteet
  theme_minimal() +scale_fill_grey() # Yksinkertainen ulkoasu

# Sektorikuvio
plot2<-ggplot(insuliini, aes(x=factor(1), fill=SOKERITASAP))+
  geom_bar(width = 1)+
  coord_polar("y") +
  theme_void() +scale_fill_grey() # Pelkistetty ulkoasu

# Järjestetään kuvaajat
grid.arrange(plot1, plot2, ncol=2) 

