## Tilastotieteen käsikirja / R-esimerkit lukuun 14
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineisto ja ggplot2 -paketti
library(nummenmaa)
library(ggplot2)

# Piirretään kuvaajat
par(mfrow=c(1,2)) # Kuvaajan asettelu
qqnorm(ciri$BMI, pch = 1, frame = FALSE) # Q-Q-kuvaaja
qqline(ciri$BMI, col = "steelblue", lwd = 2) # Lisätään viiva
plot(density(ciri$BMI), main="BMI:n tiheysfunktio") # piirretään tiheysfunktio
shapiro.test(ciri$BMI) # Shapiro-Wilkin testi 

## --------------------------------------------------------------------------------------------------------------------------------
t.test(ciri$BMI,mu=25) # Testataan onko BMI keskimäärin 25

## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään Q-Q -kuvaajat
par(mfrow=c(2,2)) # Kuvaajan asettelu
qqnorm(ciri$CERAD[ciri$PIBPOS=="Ei"], pch = 1, frame = FALSE,main="PIB-") # Q-Q
qqline(ciri$CERAD[ciri$PIBPOS=="Ei"], col = "steelblue", lwd = 2) # Lisätään viiva
qqnorm(ciri$CERAD[ciri$PIBPOS=="On"], pch = 1, frame = FALSE,main="PIB+") # Q-Q
qqline(ciri$CERAD[ciri$PIBPOS=="On"], col = "steelblue", lwd = 2) # Lisätään viiva

# Piirretään tiheysfunktiot
plot(density(ciri$CERAD[ciri$PIBPOS=="Ei"]), xlim=c(50,120),main="PIB-") 
plot(density(ciri$CERAD[ciri$PIBPOS=="On"]), xlim=c(50,120),main="PIB+") # 

## --------------------------------------------------------------------------------------------------------------------------------
# Normaalijakauma- ja varianssitestit
with(ciri,tapply(CERAD, PIBPOS, shapiro.test)) # Shapiro-Wilkin testi
var.test(CERAD ~ PIBPOS, data = ciri) # Varianssitesti

## ----fig.height=3, fig.width=4, results="hold"-----------------------------------------------------------------------------------
# Lasketaan t-testi
t.test(CERAD~PIBPOS,alternative = "two.sided", var.equal = TRUE,data=ciri) 

# Piirretään kuvaaja
ggplot(ciri, aes(x=PIBPOS,  y=CERAD, fill=PIBPOS))+ 
geom_boxplot()+theme_light()+
  labs(x="Amyloidiplakit", y = "Cerad-pistemäärä")+
    theme(legend.title = element_blank()) + # Poistetaan ylimääräinen selite
  scale_fill_brewer(palette="YlOrRd") # Väriskaala

## ----fig.height=3, fig.width=5---------------------------------------------------------------------------------------------------
# Lasketaan t-testit 
with(insuliini,t.test(PAASTOGLUK[SOKERITASAP=="T2DM"],
                      PAASTOGLUK[SOKERITASAP=="Normaali"])) # T2DM vs. Normaali

with(insuliini,t.test(PAASTOGLUK[SOKERITASAP=="T2DM"],
                      PAASTOGLUK[SOKERITASAP=="Heikentynyt"])) # T2DM vs. Heikentynyt

# Piirretään kuvaaja
     ggplot(insuliini, aes(x=SOKERITASAP, y=PAASTOGLUK, fill=SOKERITASAP))+ 
geom_boxplot()+theme_light()+
    theme(legend.title = element_blank()) + # Poistetaan ylimääräinen selite
  scale_fill_brewer(palette="YlOrRd") # Väriskaala
     
## --------------------------------------------------------------------------------------------------------------------------------
# Tehdään normaalijakaumatesti
sapply(mri[c(1,2)],shapiro.test)

# Piirretään tiheysfunktiot
par(mfrow=c(2,2)) # Kuvaajan asettelu
plot(density(mri$ARV1PYSTY), main="Pystysyynta") 
plot(density(mri$ARV1VAAKA), main="Vaakasuunta") 

# Piirretään Q-Q -kuvaajat
qqnorm(mri$ARV1PYSTY, pch = 1, main=NULL, frame = FALSE) # Q-Q-kuvaaja
qqline(mri$ARV1PYSTY, col = "steelblue", lwd = 2) # Lisätään viiva
qqnorm(mri$ARV1VAAKA, pch = 1, main=NULL,frame = FALSE) # Q-Q-kuvaaja
qqline(mri$ARV1VAAKA, col = "steelblue", lwd = 2) # Lisätään viiva

## --------------------------------------------------------------------------------------------------------------------------------
# Lasketaan t-testi
t.test(mri$ARV1PYSTY, mri$ARV2VAAKA, paired = TRUE) 

# Piirretään kuvaaja
data <- stack(mri[,c(1,2)]) # Pinotaan muuttujat
ggplot(data, aes(x=ind, y=values, fill=ind))+ # Kuvaaja
geom_boxplot()+theme_light()+ labs(x="Suunta", y="Mittaustulos") +
  theme(legend.title = element_blank()) + # Poistetaan ylimääräinen selite
  scale_fill_brewer(palette="YlOrRd")

