## Tilastotieteen käsikirja / R-esimerkit lukuun 23
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineisto ja tarvittavat paketit
library(nummenmaa)
library(ggplot2)
library(forecast)

syntyvyys$KUUKAUSI = as.Date(syntyvyys$KUUKAUSI)#,format="%y %m %d") # Määritellään pvm.
syntyvyys$LIUKUK<-ma(syntyvyys$SYNTYNEET, order=12) # Lasketaan liukuva keskiarvo

# Piirretään aikasarjakuvaaja
ggplot() +
  geom_line(data=syntyvyys, aes(x=KUUKAUSI,y=SYNTYNEET,alpha=0.5)) + 
  labs(x="Vuosi",y="Syntyneet") +
  geom_line(data=syntyvyys, aes(x=KUUKAUSI, y=LIUKUK))+
  theme_light() +theme(legend.position="none")

## --------------------------------------------------------------------------------------------------------------------------------
# Poimitaan aikasarjasta osa ja dekomponoidaan se
 sarja=ts(syntyvyys$SYNTYNEET[720:1428],frequency=12,deltat=1) # Luodaan aikasarja
  decomp = stl(sarja,s.window="periodic") # Dekomponoinoidaan aikasarja
  deseasonal_cnt <- seasadj(decomp) # Kausitasoitetaan aikasarja
  par(mfrow=c(1,1)) # Kuvaajan asettelu
  plot(decomp)

## --------------------------------------------------------------------------------------------------------------------------------
  library(tseries)
adf.test(sarja, alternative = "stationary") # DF-testi

## --------------------------------------------------------------------------------------------------------------------------------
# Testataan differointia
count_d1 = diff(deseasonal_cnt, differences = 1) # Ensimmäisen asteen differointi
adf.test(count_d1, alternative = "stationary") # DF-testi
par(mfrow=c(1,1)) # Kuvaajan asettelu
plot(count_d1) # Piirretään differoitu aikasarja

## --------------------------------------------------------------------------------------------------------------------------------
# Tarkastellaan autokorrelaatiorakennetta
par(mfrow=c(1,2)) # Kuvaajan asettelu
Acf(syntyvyys$SYNTYNEET,24,main="") # 24 viiveen kuvaaja ilman pääotsikkoa
Acf(syntyvyys$SYNTYNEET,240,main="") # 240 viiveen kuvaaja ilman pääotsikkoa

## --------------------------------------------------------------------------------------------------------------------------------
# Sovitetaan ARIMA-malli ja tarkistetaan tulokset
fit<-arima(sarja, order=c(2,1,2),seasonal = list(order = c(2,1,2),period=12)) # Malli
summary(fit) # Tarkistetaan tulokset
tsdisplay(residuals(fit), lag.max=36, main='Jäännöstermit') # Piirretään jäännöstermit

## --------------------------------------------------------------------------------------------------------------------------------
# Kokeillaan ennustamista mallin avulla
fcast <- forecast(fit, h=100)
par(mfrow=c(1,1)) # Kuvaajan asettelu
plot(fcast, main="Ennuste")

