## Tilastotieteen käsikirja / R-esimerkit lukuun 24
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineistopaketti ja tarvittavat analyysipaketit
library(nummenmaa)
library(survival)
library(survminer)

# Luodaan elinaikaolio ja tarkistetaan tulokset
elinajat<-Surv(elinaika$ELINAIKA,elinaika$KUOLLUT)
head(elinajat)

## --------------------------------------------------------------------------------------------------------------------------------
# Muodostetaan elinaikamalli ja piirretään Kaplan-Meier -käyrä
fit <- survfit(elinajat ~1,data=elinajat) # Malli
ggsurvplot(fit,conf.int=TRUE,size=0.35,palette="uchicago", # Piirretään kuvaaja
                       xlab="Aika",ylab="Eloonjäämistodennäköisyys")
fit # Tarkistetaan tulokset

## --------------------------------------------------------------------------------------------------------------------------------
res <- summary(fit)
cols <- lapply(c(2:6, 8:10) , function(x) res[x])
tbl <- round(do.call(data.frame, cols),2)
tbl[1:10,]

## --------------------------------------------------------------------------------------------------------------------------------
# Muodostetaan elinaikamalli ja piirretään Kaplan-Meier -käyrä
fit <- survfit(elinajat ~SUKUP, data = elinaika) # Malli
ggsurvplot(fit,conf.int=TRUE,pval=TRUE, size=0.35,palette="uchicago",
           xlab="Aika",ylab="Eloonjäämistodennäköisyys") # # Piirretään Kaplan-Meier -käyrä
survdiff(elinajat~ SUKUP,data=elinaika) # Lasketaan logrank-testi

## --------------------------------------------------------------------------------------------------------------------------------
# Muodostetaan Coxin regressiomalli
res.cox<-coxph(elinajat~AIVOMETAB+ASUINPAIKKA, data=elinaika) # Malli
summary(res.cox) # Tarkistetaan tulokset

