## Tilastotieteen käsikirja / R-esimerkit lukuun 28
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineistopaketti 
library(nummenmaa)
par(mfrow=c(1,2)) # Kuvaajan asettelu 

# Piirretään laatikko-jana -kuvio
boxplot(dopamiini[,3:4],names=c("Verrokit", "Potilaat"),
        ylab="Dopamiinitaso") 

# Piirretään estimoitu tiheysfunktio
plot(density(dopamiini$KA_PARKINSON), xlim=c(0,15),main="", xlab="") # Verrokit
lines(density(dopamiini$KA_KONTROLLI)) # Lisätään potilaat

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan metafor- ja ggplot2 -paketit ja lasketaan efektikoot
library(metafor)
library(ggplot2)
meta <- escalc(n1i = N_PARKINSON, n2i = N_KONTROLLI, m1i = KA_PARKINSON, m2i = KA_KONTROLLI, 
    sd1i = SD_PARKINSON, sd2i = SD_KONTROLLI, data = dopamiini, measure = "SMD", 
    append = TRUE) # Lasketaan efektikoot

## --------------------------------------------------------------------------------------------------------------------------------
# Sovitetaan meta-analyysimalli
meta <- meta[order(meta$yi),] # Järjestetään tietokehikko efektikoon mukaan
metamalli<- rma(yi, vi, data = meta) # Lasketaan meta-analyysi
summary(metamalli) # Tarkistetaan tulokset

## --------------------------------------------------------------------------------------------------------------------------------
par(mfrow=c(1,1)) # Kuvaajan asettelu
forest(metamalli, slab = paste(meta$TUTKIMUS), cex=0.8, xlim=c(-16,4)) # Forest plot

## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään kuvaajat tuloksien arvioimista varten
par(mfrow=c(1,2)) # Kuvaajan asettelu
funnel(metamalli) # Suppilokuvaaja
par(mar=c(0,4,0,1)) # Säädetään marginaaleja Galbraith-kuvaajaa varten
radial(metamalli) # Galbraith-kuvaaja


## --------------------------------------------------------------------------------------------------------------------------------
# Muodostetaan metaregressiomalli
metaregressio<- rma(yi, vi,mods = ~KESTO, data = meta) # Metaregressiomalli
summary(metaregressio) # Tarkistetaan tulokset

## --------------------------------------------------------------------------------------------------------------------------------
par(mfrow=c(1,1)) # Kuvaajan asettelu
plot(meta$KESTO,meta$yi,xlab="Kesto",ylab="Efektikoko") # Piirretään sirontakuvio

