## Tilastotieteen käsikirja / R-esimerkit lukuun 29
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineistopaketti
library(nummenmaa)

# Muodostetaan malli ja tarkistetaan tulokset
log.res <- glm(DIABETES ~ IKA + BMI + PAASTOGLUK + DIASTVP, 
               data = insuliini, family = "binomial") # Malli
summary(log.res) # Tarkistetaan tulokset

## --------------------------------------------------------------------------------------------------------------------------------# Tarkastellaan mallin antamia ennusteita
ennusteet <- predict(log.res,type = "response") # Lasketaan ennusteet 
insuliini$ENNUSTE<-ifelse(ennusteet < 0.5, "Ei", "On") # Tallennetaan kaksiluokkaisena
ennustejakauma<-prop.table(table(insuliini$ENNUSTE,
                                 insuliini$DIABETES),2)*100 # Ristiintaulukoidaan
round(ennustejakauma,0) # Kuvataan taulukko
par(mfrow=c(1,1)) # Kuvaajan asettelu
barplot(ennustejakauma,legend=TRUE,xlab="Luokka", ylab="Ennuste") # Pylväskuvaaja

## --------------------------------------------------------------------------------------------------------------------------------
# Lasketaan selitysaste
nolla.res <- glm(DIABETES~1, data = insuliini, family="binomial")
1-logLik(log.res)/logLik(nolla.res)

## --------------------------------------------------------------------------------------------------------------------------------# Ladataan ristiinvalidointiin tarvittava paketti
library(caTools)

# Muodostetaan opetus- ja testiaineistot
set.seed(230377) # Vakioidaan satunnaistaminen
split <- sample.split(insuliini$DIABETES, SplitRatio = 0.75) # Jaetaan suhteessa 25/75
opetus <- subset(insuliini, split == TRUE) # Tehdään opetusaineisto
testi <- subset(insuliini, split == FALSE) # Tehdään testianeisto

## --------------------------------------------------------------------------------------------------------------------------------# Ladataan ristiinvalidointiin tarvittava paketti
# Ristiinvalidoidaan logistinen regressiomalli
log.res <- glm(DIABETES ~ IKA + BMI + PAASTOGLUK + DIASTVP, 
               data = opetus, family = "binomial") # Malli
ennusteet <- predict(log.res,newdata = testi, type = "response") # Ennusteet testiaineistolle
testi$ENNUSTE<-ifelse(ennusteet < 0.5, "Ei", "On") # Tallennetaan kaksiluokkaisena 
ennustej<-prop.table(table(testi$ENNUSTE,testi$DIABETES),2)*100 # Ristiintaulukoidaan 
round(ennustej,0) # Kuvataan taulukko
barplot(ennustej,legend=TRUE,xlab="Luokka", ylab="Ennuste") # Esitetään pylväskuvaajana

## --------------------------------------------------------------------------------------------------------------------------------
# Muokataan aineisto analyysia varten
fvaalit<-vaalit[complete.cases(vaalit), ] # Poimitaan vain kaikkiin vastanneet 
fvaalit<-subset(fvaalit,PUOLUE=="SDP" | PUOLUE=="Kokoomus" | PUOLUE=="Keskusta" |
                   PUOLUE=="Perussuomalaiset" ) # Valitaan isoimmat puolueet
fvaalit<-fvaalit[ ,c(2,5:33)] # Poistetaan ylimääräiset muuttujat
fvaalit$PUOLUE <- factor(fvaalit$PUOLUE) # Poistetaan ylimääräiset luokkanimiöt

## --------------------------------------------------------------------------------------------------------------------------------# Ladataan ristiinvalidointiin tarvittava paketti
# Ladataan analyysi- ja grafiikkapaketit
library(MASS)
library(ggplot2)

# Lasketaan erotteluanalyysi
lda.model <- lda(PUOLUE~ ., data = fvaalit) # Malli
lda.data <- cbind(fvaalit, predict(lda.model)$x) # Laaditaan ennusteet
ggplot(lda.data) + # Kuvataan havainnot kahden diskriminantin avulla
  geom_point(aes(LD1,LD2,colour=PUOLUE,shape=PUOLUE), size=2)+
theme_light() +scale_color_grey()

## --------------------------------------------------------------------------------------------------------------------------------
# Ristiinvalidoidaan erotteluanalyysin tulokset leave-one-out -menetelmällä
lda.model <- lda(PUOLUE~ ., data = fvaalit, CV=TRUE) # Tehdään malli
tulokset <- table(fvaalit$PUOLUE, lda.model$class) # Ristiintaulukoidaan 
tulokset # Tarkistetaan tulokset
diag(prop.table(tulokset, 1)) # Ennustetaulukko
sum(diag(prop.table(tulokset))) # Ennustetarkkuus

## --------------------------------------------------------------------------------------------------------------------------------
# Ristiinvalidoidaan erotteluanalyysin tulokset opetus- ja testiaineisotoilla
set.seed(230377) # Vakioidaan satunnaistaminen
split <- sample.split(fvaalit$PUOLUE, SplitRatio = 0.50) # Jaetaan suhteessa 50 / 50
opetus <- subset(fvaalit, split == TRUE) # Tehdään opetusaineisto
testi <- subset(fvaalit, split == FALSE) # Tehdään testianeisto

lda.model <- lda(PUOLUE~ ., data = opetus) # Malli
validointi <-predict(lda.model, newdata=testi) # Validoidaan uudella aineistolla
tulokset <- table(testi$PUOLUE, validointi$class)
tulokset # Tarkistetaan tulokset
diag(prop.table(tulokset, 1)) # Ennustetaulukko
sum(diag(prop.table(tulokset))) # Ennustetarkkuus

