## Tilastotieteen käsikirja / R-esimerkit lukuun 31
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineistopaketti ja valmistellaan aineisto
library(nummenmaa)
fvaalit<-vaalit[complete.cases(vaalit), ] # Poimitaan vain kaikkiin vastanneet
fvaalit[,5:33]<-scale(fvaalit[,5:33]) # Standardoidaan vastaukset
puolueittain<-aggregate(fvaalit[, 5:33], 
                        list(fvaalit$PUOLUE), mean) # Lasketaan keskiarvot puolueittain

# Nimetään puolue-muuttuja uudelleen
colnames(puolueittain)[colnames(puolueittain)=="Group.1"] <- "PUOLUE" 

## --------------------------------------------------------------------------------------------------------------------------------
# Muodostetaan asteikointiratkaisu
etaisyys<-dist(fvaalit[,5:33]) #standardoidaan vastaukset
fit <- cmdscale(etaisyys,eig=TRUE,k=2) # k ulottuvuutta
x <- fit$points[,1]
y <- fit$points[,2]
par(mfrow=c(1,1)) # Kuvaajan asettelu
plot(x,y,col=fvaalit$PUOLUE,pch=16,xlim=c(-7,13),ylim=c(-7,5)) 
legend("bottomright",levels(fvaalit$PUOLUE),
       col=seq(along=levels(fvaalit$PUOLUE)),pch=15,cex=0.75)

## --------------------------------------------------------------------------------------------------------------------------------
# Muodostetaan asteikointiratkaisu puolueiden keskiarvovastauksille
etaisyys<-dist(puolueittain[,2:30]) # Lasketaan etäisyysmatriisi
fit <- cmdscale(etaisyys,eig=TRUE, k=2) # Muodostetaan asteikointiratkaisu 
x <- fit$points[,1] # Poimitaan ensimmäinen ulottuvuus tuloksista
y <- fit$points[,2] # Poimitaan toinen ulottuvuus tuloksista
plot(x, y, xlab="Ei-perinteinen - perinteinen", ylab="Vasemmisto-oikeisto", 
     main="Metrinen MDS", pch=16,xlim=c(-7,7),ylim=c(-4,4),col="darkgray")
text(x, y, labels = levels(puolueittain$PUOLUE),pos=3,col="blue",cex = 0.9)


## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään siistimpi kuvaaja
library(ggpubr) # Tarvitaan kuvaajan piirtämiseen
piirrettava<-data.frame(PUOLUE=puolueittain$PUOLUE, x=x,y=y)
ggscatter(piirrettava, x = "y", y = "x", 
          label = (piirrettava$PUOLUE),
          xlab="Vasemmisto-oikeisto",
          ylab="Ei-perinteinen - perinteinen", 
          size = 1,
          repel = TRUE)

## --------------------------------------------------------------------------------------------------------------------------------
# Lasketaan ei-metrinen asteikointiratkaisu
library(MASS) # Tarvitaan non-metrisen MDS:n laskemiseen
etaisyys<-dist(puolueittain[,2:30]) # lasketaan etäisyysmatriisi
fit <- isoMDS(etaisyys, k=2) # k Ulottuvuuksien lukumäärä, nyt 2

## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään kuvaaja
x <- fit$points[,1]
y <- fit$points[,2]
piirrettava<-data.frame(PUOLUE=puolueittain$PUOLUE, x=x,y=y)
ggscatter(piirrettava, x = "y", y = "x", 
          label = (piirrettava$PUOLUE),
          xlab="Vasemmisto-oikeisto", ylab="Ei-perinteinen - perinteinen",
          size = 1,
          repel = TRUE)

