## Tilastotieteen käsikirja / R-esimerkit lukuun 32
## (C) 2021 Lauri Nummenmaa / Tammi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineistopaketti ja valmistellaan aineisto
library(nummenmaa)
rownames(hevi) <- hevi[, 1] # Tallennetaan bändien nimet rivien nimiksi
hevi <- hevi[, -1]          # Poistetaan bändien nimimuuttuja

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan analyysipaketti ja lasketaan PCA
library(factoextra)
pca<-prcomp(hevi,center = TRUE,scale. = TRUE) # Ajataan PCA
summary(pca) # Tarkistetaan tulokset

## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään jyrkännekuvio
fviz_screeplot(pca, addlabels = TRUE, ylim = c(0, 35),
               barfill="white", barcolor ="darkblue",
               linecolor ="red") # Piirretään komponenttien selitysvoima

## --------------------------------------------------------------------------------------------------------------------------------
# Projisoidaan muuttujat komponenteille
fviz_pca_var(pca, col.var = "cos2",repel = TRUE) 

## --------------------------------------------------------------------------------------------------------------------------------
# Valmistellaan aineisto
image_matrix<-kasvot
nimet <- image_matrix[, 1] # otetaan kuvien nimet erilleen tietokehikosta
data<-data.matrix(image_matrix[,2:4097], rownames.force = NA) # tallennetaan  matriisiksi

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan kuvankäsittelypaketti
library(OpenImageR)

## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään kaikki kasvot
par(mfrow=c(15,10),mar=c(0.25,0.25,0.25,0.25), oma=c(0.5,0.5,0.5,0.5)) # Kuvaajan asettelu
for (plotim in 1:150){
image(t(apply(matrix(data[plotim,],nrow=64,byrow=TRUE),1,rev)),col= gray((0:256)/256),axes=FALSE)
}

## --------------------------------------------------------------------------------------------------------------------------------
# Lasketaan PCA
pca<-prcomp(data,center = TRUE,scale. = TRUE) # PCA standardoiden

# Piirretään komponenttien selitysvoima
fviz_screeplot(pca, addlabels = TRUE, ylim = c(0, 35),
               barfill="white", barcolor ="darkblue",
               linecolor ="red") 

## --------------------------------------------------------------------------------------------------------------------------------
# Piirretään keskiarvokasvot ja 3 komponenttikasvoa
par(mfrow=c(1,4),oma=c(1,1,1,1),mar=c(1,1,1,1)) # Kuvan asetukset
keskiarvo=colMeans(data) # Keskiarvokasvot eli muuttujien keskiarvovektori
image(t(apply(matrix(keskiarvo, nrow = 64, byrow = TRUE),1,rev)),col= gray((0:256)/256),main = "Keskiarvo",axes=FALSE) # Piirretään keskiarvokuva marix:n avulla kuten yllä
image(t(apply(matrix(pca$rotation[,1],nrow=64, byrow = TRUE),1,rev)),col= gray((0:256)/256),main = "PC1",axes=FALSE) # Piirretään komponenttikasvot 1-3
image(t(apply(matrix(pca$rotation[,2],nrow=64, byrow = TRUE),1,rev)),col= gray((0:256)/256),main = "PC2",axes=FALSE)
image(t(apply(matrix(pca$rotation[,3],nrow=64, byrow = TRUE),1,rev)),col= gray((0:256)/256),main = "PC3",axes=FALSE)

## --------------------------------------------------------------------------------------------------------------------------------
# Projisoidaan data PCA-avaruuteen 25 komponentilla. 
restr <- pca$x[,1:25] %*% t(pca$rotation[,1:25]) 

# Piirretään alkuperäiset kasvot 
par(mfrow=c(2,4),oma=c(1,1,1,1),mar=c(2,2,2,2)) 
image(t(apply(matrix(data[19,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "Bruce Springsteen")
image(t(apply(matrix(data[22,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "Cameron Diaz")  
image(t(apply(matrix(data[40,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "Elvis Presley")  
image(t(apply(matrix(data[42,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "Emma Watson") 

# Piirretään PC-rekonstruktiokasvot
image(t(apply(matrix(restr[19,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "PC-rekonstruktio")
image(t(apply(matrix(restr[22,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "PC-rekonstruktio")
image(t(apply(matrix(restr[40,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "PC-rekonstruktio")
image(t(apply(matrix(restr[42,],nrow=64,byrow=TRUE),1,rev)),
      col= gray((0:256)/256),axes=FALSE,main = "PC-rekonstruktio")

