## Tilastotieteen käsikirja / R-esimerkit lukuun 34
## (C) 2021 Lauri Nummenmaa / Tammi

## ----warning=FALSE,message=FALSE-------------------------------------------------------------------------------------------------
# Ladataan analyysipaketit ja aineisto
library(nummenmaa)
library(lavaan)
library(lavaanPlot)

## --------------------------------------------------------------------------------------------------------------------------------
reg.model <- '
y1 ~ x1 + x2 + x3 # Regressiomalli
y1~y1 # Määrietllään y-muuttujan varianssi
y1 ~ 1 # Lisätään vakiotermi
'
reg.fit<-sem(reg.model,data=rakenne)
lavaanPlot(model=reg.fit)

## --------------------------------------------------------------------------------------------------------------------------------
path.model <- '
# Muuttujan x1 suora vaikutus
  y1 ~ c*x1 
# Muuttujan x1 mediaatiovaikutus y2:n kautta
  y2 ~ a*x1 
  y1 ~ b*y2 
# Epäsuora vaikutus
  ab:=a*b
# Vaikutus yhteensä
  total:=c+(a*b)
'
path.fit<-sem(path.model,data=rakenne)
lavaanPlot(model=path.fit)

## --------------------------------------------------------------------------------------------------------------------------------
fact.model <- '
Lat1 =~ x1 + x2 + x3 # Ensimmäinen faktori
Lat2 =~ y1 + y2 + y3 # Toinen faktori
'
fact.fit<-sem(fact.model,data=rakenne)
lavaanPlot(model=fact.fit)

## --------------------------------------------------------------------------------------------------------------------------------
sem.model <- '
# Mittausmalli
  Lat1 =~ x1 + x2 + x3
  Lat2 =~ y1 + y2 + y3 + y4
  Lat3 =~ y5 + y6 + y7 + y8
# Rakennemalli
  Lat2 ~ Lat1
  Lat3 ~ Lat1 + Lat2
# Jäännösvarianssien vapauttaminen  
  y1 ~~ y5
  y2 ~~ y4 + y6
'
sem.res<-sem(sem.model,data=rakenne)
lavaanPlot(model=sem.res)

## --------------------------------------------------------------------------------------------------------------------------------
# Ladataan aineisto ja grafiikkapaketti
library(ggpubr)

# Tarkastetaan korrelaatiomatriisi
round(cor(alykkyys[,5:13]),2) 

# Poimitaan muuttujat kuvaajien piirtämistä varten
vis <- stack(alykkyys[,5:7]) # Visuaaliset tehtävät
kiel <- stack(alykkyys[,8:10]) # Kielelliset tehtävät
nop <- stack(alykkyys[,11:13]) # Nopeustehtävät

# Piirretään tiheysfunktiot
vplot1<-ggdensity(vis,x="values",color="ind", fill="ind",alpha=0.7) 
kplot1<-ggdensity(kiel,x="values",color="ind", fill="ind",alpha=0.7) 
nplot1<-ggdensity(nop,x="values",color="ind", fill="ind",alpha=0.7) 

# Piirretään Q-Q -kuvaajat
vplot2<-ggqqplot(vis,x="values",color="ind", fill="ind")
kplot2<-ggqqplot(kiel,x="values",color="ind", fill="ind")
nplot2<-ggqqplot(nop,x="values",color="ind", fill="ind") 

# Järjestetään kuvaajat
ggarrange(vplot1, kplot1, nplot1, vplot2, kplot2, nplot2, nrow=2, ncol=3) 

## --------------------------------------------------------------------------------------------------------------------------------
sem.model <- ' 
# Mittausmalli
  Visuaalinen =~ VIS1 + VIS2 + VIS3
  Kielellinen =~ KIEL1 + KIEL2 + KIEL3
  Nopeus =~ NOP1 + NOP2 + NOP3
# Rakennemalli
  Visuaalinen ~ Nopeus
  Kielellinen ~ Nopeus
'
sem.res<-sem(sem.model,data=alykkyys)
lavaanPlot(model=sem.res,coefs=TRUE)

## --------------------------------------------------------------------------------------------------------------------------------
summary(sem.res, fit.measures=TRUE) # Tarkistetaan tulokset

## --------------------------------------------------------------------------------------------------------------------------------
residuals(sem.res, type = "cor")

